@@ -1,7 +1,6 @@
-from . import test
 from . import analysis
 from . import datasets
 from . import downloads
 from . import loader
-#from . import metrics
+from . import metrics
 from . import splits
\ No newline at end of file
